function wSolnVec = OrthoEstMirrorDistRatio( polyBoundaryVecCell, normalAngle, RR_Rec, allViews )

%This function uses the silhouettes 2 and 3 to approximate the ratio of
%distances from the camera centres to the mirrors. 
%
%In principle, one could combine estimates from other pairs of silhouettes
%too -- but this would be a lot of coding for little benefit in increased
%accuracy, as Levenberg Marquardt easily turns the approximate solution
%into a very good solution.

numImages = length(polyBoundaryVecCell);

R = [cos(normalAngle) -sin(normalAngle) 0; sin(normalAngle) cos(normalAngle) 0; 0 0 1]; %rotate about Z-axis

m1Base =     [1;0;0];
m2Base = R * [1;0;0];

for imgLoop = 1:numImages,    
    RR = RR_Rec{imgLoop};
    m1Hat = RR * m1Base;       
    m2Hat = RR * m2Base;
    
    M1_pos = -m1Hat;    
    M2_pos = -m2Hat;
    
    poseGreen = ReflectionMatrixFromVecPoint( m1Hat, M1_pos );
    poseBlue = ReflectionMatrixFromVec( m2Hat );
    
    greenCamDirRefBlue = poseBlue(1:3,1:3) *...
        inv( poseGreen(1:3,1:3) ) * [0;0;1];
    
    blueCamDirRefGreen = poseGreen(1:3,1:3) *...
        inv( poseBlue(1:3,1:3) ) * [0;0;1];
    
    
    crossDir = cross( inv( poseBlue(1:3,1:3) ) * [0;0;1], inv( poseGreen(1:3,1:3) ) * [0;0;1] );
    %This is a direction perpendicular to the two viewing directions that
    %will be used to specify the correspondence between the two pairs of
    %tangencies. The tangencies on the same side of the object (as specified
    %by crossDir) correspond
    
    crossDirRefGreen = poseGreen(1:3,1:3) * crossDir;
    crossDirRefBlue = poseBlue(1:3,1:3) * crossDir;
    
    
    [aIndBlue,bIndBlue] = OrthoTangencies( polyBoundaryVecCell{imgLoop}{3}, greenCamDirRefBlue(1:2) );    
    
    if [-greenCamDirRefBlue(2),greenCamDirRefBlue(1)] * crossDirRefBlue(1:2) < 0 
        [aIndBlue,bIndBlue] = swap(aIndBlue,bIndBlue);
    end
    
    [aIndGreen,bIndGreen] = OrthoTangencies(  polyBoundaryVecCell{imgLoop}{2}, blueCamDirRefGreen(1:2) );
    
    if [-blueCamDirRefGreen(2),blueCamDirRefGreen(1)] * crossDirRefGreen(1:2) < 0 
        [aIndGreen,bIndGreen] = swap(aIndGreen,bIndGreen);
    end
    
    
    [m1_11, m1_12, m1_13, m1_14] = MyDeal(poseGreen(1,:));
    [m1_21, m1_22, m1_23, m1_24] = MyDeal(poseGreen(2,:));
    [m1_31, m1_32, m1_33, m1_34] = MyDeal(poseGreen(3,:));
    [m2_11, m2_12, m2_13] = MyDeal(poseBlue(1,:));
    [m2_21, m2_22, m2_23] = MyDeal(poseBlue(2,:));
    [m2_31, m2_32, m2_33] = MyDeal(poseBlue(3,:));
    
    [nx, ny, nz] = MyDeal( m2Hat );
    
    [pV1xNi, pV1yNi] = MyDeal( ImageToNormalisedImage( polyBoundaryVecCell{imgLoop}{2}(:,aIndGreen), allViews.camera) );    
    [pV2xNi, pV2yNi] = MyDeal( ImageToNormalisedImage( polyBoundaryVecCell{imgLoop}{3}(:,aIndBlue), allViews.camera) );        
    wSolnA = -1/2*(-m1_24*m1_13*m2_21*m2_12-m2_11*m1_24*m1_12*m2_23+m2_11*m1_14*m1_22*m2_23+m1_14*m1_23*m2_21*m2_12-m1_14*m1_22*m2_21*m2_13-m1_14*m1_21*m2_12*m2_23+m1_24*m1_11*m2_12*m2_23+m1_24*m1_12*m2_21*m2_13+m2_22*m2_11*pV1xNi*m1_34*m1_23+m2_22*m2_11*m1_24*m1_13+m2_22*m1_14*m1_21*m2_13-m2_22*m2_11*m1_14*m1_23-m2_11*pV1yNi*m1_14*pV2yNi*m1_33*m2_32+m2_33*m2_22*pV1yNi*m1_14*pV2xNi*m1_31+m2_11*pV1xNi*m1_24*pV2yNi*m1_33*m2_32+m2_22*m1_14*pV2xNi*m1_23*m2_31-m2_11*pV1xNi*m1_34*m1_22*m2_23+m2_11*pV1yNi*m1_34*pV2yNi*m1_13*m2_32-m2_11*pV1yNi*m1_14*m1_32*m2_23+m2_33*m1_14*pV2xNi*m1_22*m2_21-m2_11*pV1xNi*m1_34*pV2yNi*m1_23*m2_32-m2_33*m1_24*pV2yNi*m1_11*m2_12-m2_33*m1_24*pV2xNi*m1_12*m2_21-m2_33*m2_11*m1_14*pV2yNi*m1_22+m2_33*m2_11*m1_24*pV2yNi*m1_12+m2_33*m1_14*pV2yNi*m1_21*m2_12+m2_33*pV1xNi*m1_24*pV2yNi*m1_31*m2_12-m2_33*pV1xNi*m1_34*pV2yNi*m1_21*m2_12-m2_33*pV1yNi*m1_14*pV2yNi*m1_31*m2_12+m2_33*m2_22*m1_24*pV2xNi*m1_11-m2_33*m2_22*pV1xNi*m1_24*pV2xNi*m1_31+m2_11*pV1xNi*m1_24*m1_32*m2_23+m2_33*m2_22*pV1xNi*m1_34*pV2xNi*m1_21+m2_33*pV1yNi*m1_34*pV2xNi*m1_12*m2_21-m2_33*pV1xNi*m1_34*pV2xNi*m1_22*m2_21+m2_33*pV1xNi*m1_24*pV2xNi*m1_32*m2_21-m2_33*pV1yNi*m1_14*pV2xNi*m1_32*m2_21+m2_33*m2_11*pV1xNi*m1_34*pV2yNi*m1_22-m2_33*m2_11*pV1xNi*m1_24*pV2yNi*m1_32-m2_33*m2_11*pV1yNi*m1_34*pV2yNi*m1_12+m2_33*m2_11*pV1yNi*m1_14*pV2yNi*m1_32-m2_33*m2_22*pV1yNi*m1_34*pV2xNi*m1_11-m2_33*m2_22*m1_14*pV2xNi*m1_21+m2_11*m1_14*pV2yNi*m1_23*m2_32-m2_11*m1_24*pV2yNi*m1_13*m2_32+m1_24*pV2xNi*m1_12*m2_31*m2_23+m1_24*pV2xNi*m1_13*m2_21*m2_32+m1_24*pV2yNi*m1_11*m2_32*m2_13-m1_24*pV2yNi*m1_12*m2_31*m2_13+m1_24*pV2yNi*m1_13*m2_31*m2_12+pV1yNi*m1_34*pV2xNi*m1_11*m2_32*m2_23+pV1xNi*m1_34*pV2yNi*m1_23*m2_31*m2_12-m1_14*pV2yNi*m1_21*m2_32*m2_13+m1_14*pV2yNi*m1_22*m2_31*m2_13-m1_14*pV2xNi*m1_22*m2_31*m2_23-m1_14*pV2yNi*m1_23*m2_31*m2_12-m1_24*pV2xNi*m1_11*m2_32*m2_23+pV1yNi*m1_34*m1_13*m2_21*m2_12-pV1yNi*m1_34*m1_11*m2_12*m2_23-m1_14*pV2xNi*m1_23*m2_21*m2_32+m2_11*pV1yNi*m1_34*m1_12*m2_23+pV1xNi*m1_24*pV2xNi*m1_31*m2_32*m2_23-pV1xNi*m1_34*pV2xNi*m1_21*m2_32*m2_23-pV1yNi*m1_34*m1_12*m2_21*m2_13-pV1xNi*m1_24*m1_31*m2_12*m2_23+pV1xNi*m1_34*m1_21*m2_12*m2_23-pV1yNi*m1_34*pV2xNi*m1_12*m2_31*m2_23-pV1yNi*m1_34*pV2xNi*m1_13*m2_21*m2_32-pV1yNi*m1_34*pV2yNi*m1_11*m2_32*m2_13+pV1yNi*m1_34*pV2yNi*m1_12*m2_31*m2_13-pV1yNi*m1_34*pV2yNi*m1_13*m2_31*m2_12+pV1xNi*m1_34*pV2yNi*m1_21*m2_32*m2_13+pV1xNi*m1_34*pV2xNi*m1_23*m2_21*m2_32-pV1xNi*m1_24*pV2xNi*m1_33*m2_21*m2_32-pV1xNi*m1_24*pV2yNi*m1_31*m2_32*m2_13-pV1xNi*m1_24*pV2yNi*m1_33*m2_31*m2_12+pV1xNi*m1_24*pV2yNi*m1_32*m2_31*m2_13+pV1xNi*m1_34*pV2xNi*m1_22*m2_31*m2_23+pV1yNi*m1_14*pV2xNi*m1_33*m2_21*m2_32+pV1yNi*m1_14*pV2yNi*m1_31*m2_32*m2_13-pV1yNi*m1_14*pV2yNi*m1_32*m2_31*m2_13+pV1yNi*m1_14*pV2yNi*m1_33*m2_31*m2_12+pV1yNi*m1_14*m1_31*m2_12*m2_23-pV1yNi*m1_14*m1_33*m2_21*m2_12+pV1yNi*m1_14*m1_32*m2_21*m2_13-pV1xNi*m1_24*pV2xNi*m1_32*m2_31*m2_23-pV1yNi*m1_14*pV2xNi*m1_31*m2_32*m2_23+pV1yNi*m1_14*pV2xNi*m1_32*m2_31*m2_23+pV1xNi*m1_24*m1_33*m2_21*m2_12-pV1xNi*m1_24*m1_32*m2_21*m2_13+m1_14*pV2xNi*m1_21*m2_32*m2_23-pV1xNi*m1_34*pV2yNi*m1_22*m2_31*m2_13-pV1xNi*m1_34*m1_23*m2_21*m2_12+pV1xNi*m1_34*m1_22*m2_21*m2_13-m2_22*pV1xNi*m1_34*m1_21*m2_13-m2_22*pV1yNi*m1_14*m1_31*m2_13+m2_22*pV1xNi*m1_24*pV2xNi*m1_33*m2_31-m2_22*m1_24*pV2xNi*m1_13*m2_31+m2_22*pV1xNi*m1_24*m1_31*m2_13+m2_22*pV1yNi*m1_34*pV2xNi*m1_13*m2_31+m2_22*pV1yNi*m1_34*m1_11*m2_13-m2_22*m2_11*pV1xNi*m1_24*m1_33-m2_22*m2_11*pV1yNi*m1_34*m1_13+m2_22*m2_11*pV1yNi*m1_14*m1_33-m2_22*pV1yNi*m1_14*pV2xNi*m1_33*m2_31-m2_22*m1_24*m1_11*m2_13-m2_22*pV1xNi*m1_34*pV2xNi*m1_23*m2_31+m2_33*pV1yNi*m1_34*pV2yNi*m1_11*m2_12)/(-pV1xNi*m1_31*nx*ny^2*pV2yNi*m1_23*m2_32+pV1xNi*m1_23*nz*nx^2*pV2yNi*m1_31*m2_12-m2_11*m1_13*nz^3*pV2yNi*m1_22+m1_11*nx^3*m1_22*m2_23+m2_22*pV1yNi*m1_13*nz*nx^2*pV2xNi*m1_31-m2_22*pV1xNi*m1_23*nz*nx^2*pV2xNi*m1_31+pV1xNi*m1_22*ny^3*m1_31*m2_13+m1_11*nx*nz^2*m1_22*m2_23-m2_33*pV1yNi*m1_32*ny*nx^2*pV2xNi*m1_11-pV1yNi*m1_13*nz*nx^2*pV2xNi*m1_32*m2_21-pV1xNi*m1_33*m2_31*nx*ny^2*pV2yNi*m1_22+pV1xNi*m1_23*m2_31*nx*nz^2*pV2yNi*m1_32+pV1yNi*m1_31*nx^3*m1_12*m2_23+pV1yNi*m1_31*nx*ny^2*pV2yNi*m1_13*m2_32+m2_22*m1_21*nx^3*m1_13-m2_11*pV1xNi*m1_22*ny^3*m1_33-pV1xNi*m1_33*ny*m2_32*nx^2*pV2xNi*m1_21-pV1yNi*m1_13*m2_31*nx*nz^2*pV2yNi*m1_32-pV1xNi*m1_32*m2_21*nx^3*m1_23+m2_33*pV1xNi*m1_32*ny*nz^2*pV2xNi*m1_21+m1_11*m2_12*ny^3*m1_23-pV1xNi*m1_33*ny*m2_32*nz^2*pV2xNi*m1_21+m1_12*m2_21*nx*nz^2*m1_23-m1_23*nz^3*pV2yNi*m1_11*m2_12-m2_22*m1_11*nx^3*m1_23+m1_12*ny^3*m1_21*m2_13-pV1yNi*m1_13*ny*m2_32*nz^2*pV2xNi*m1_31-pV1xNi*m1_32*ny*nz^2*pV2xNi*m1_23*m2_31+m1_11*m2_12*ny*nz^2*m1_23+m2_22*pV1yNi*m1_11*nx*ny^2*m1_33-m2_22*pV1yNi*m1_31*nx^3*m1_13+m2_22*pV1yNi*m1_11*nx*nz^2*m1_33-m2_22*pV1yNi*m1_33*nz^3*pV2xNi*m1_11-m2_22*pV1xNi*m1_21*nx*nz^2*m1_33-m2_22*m1_11*nx*ny^2*m1_23+m2_22*pV1xNi*m1_31*nx^3*m1_23-m2_22*m1_13*nz*ny^2*pV2xNi*m1_21-m2_22*pV1yNi*m1_31*nx*nz^2*m1_13+m2_22*m1_23*nz*nx^2*pV2xNi*m1_11+m2_22*pV1yNi*m1_11*nx^3*m1_33-m2_22*pV1yNi*m1_33*nz*ny^2*pV2xNi*m1_11+m2_22*pV1yNi*m1_13*nz*ny^2*pV2xNi*m1_31+m2_22*pV1xNi*m1_33*nz*nx^2*pV2xNi*m1_21+m2_22*pV1xNi*m1_33*nz*ny^2*pV2xNi*m1_21+m2_22*m1_21*nx*nz^2*m1_13+m2_22*pV1xNi*m1_31*nx*nz^2*m1_23+m2_22*pV1xNi*m1_33*nz^3*pV2xNi*m1_21-pV1xNi*m1_32*m2_23*nz*nx^2*pV2xNi*m1_21+pV1yNi*m1_32*m2_23*nz*nx^2*pV2xNi*m1_11-m1_23*nz*ny^2*pV2yNi*m1_11*m2_12-pV1xNi*m1_32*ny^3*pV2xNi*m1_23*m2_31-pV1xNi*m1_33*nz*ny^2*pV2xNi*m1_22*m2_21-pV1xNi*m1_33*nz*ny^2*pV2yNi*m1_21*m2_12-pV1xNi*m1_32*m2_23*nz^3*pV2xNi*m1_21+pV1xNi*m1_21*nx*nz^2*pV2yNi*m1_33*m2_32-m2_11*pV1xNi*m1_22*ny*nz^2*m1_33+m1_13*nz*ny^2*pV2yNi*m1_21*m2_12-m1_23*m2_31*nx*ny^2*pV2yNi*m1_12-pV1yNi*m1_11*nx^3*m1_32*m2_23+pV1yNi*m1_32*ny^3*m1_11*m2_13+pV1yNi*m1_33*nz*nx^2*pV2yNi*m1_11*m2_12+pV1yNi*m1_33*m2_31*nx^3*pV2yNi*m1_12+pV1yNi*m1_33*m2_31*nx*ny^2*pV2yNi*m1_12+pV1yNi*m1_33*m2_31*nx*nz^2*pV2yNi*m1_12+pV1yNi*m1_33*nz*ny^2*pV2xNi*m1_12*m2_21+pV1xNi*m1_23*m2_31*nx^3*pV2yNi*m1_32-m1_23*ny*m2_32*nx^2*pV2xNi*m1_11-m2_22*pV1xNi*m1_21*nx*ny^2*m1_33+m2_22*pV1xNi*m1_31*nx*ny^2*m1_23-m2_22*pV1xNi*m1_23*nz^3*pV2xNi*m1_31-m2_22*m1_13*nz^3*pV2xNi*m1_21-m2_22*m1_11*nx*nz^2*m1_23+m2_22*m1_23*nz*ny^2*pV2xNi*m1_11-m2_22*pV1yNi*m1_31*nx*ny^2*m1_13-pV1xNi*m1_31*nx^3*pV2yNi*m1_23*m2_32-pV1xNi*m1_31*m2_13*nz^3*pV2yNi*m1_22-pV1xNi*m1_32*ny*nz^2*m1_21*m2_13-pV1xNi*m1_32*m2_21*nx*ny^2*m1_23-m1_22*m2_23*nz*nx^2*pV2xNi*m1_11-pV1xNi*m1_31*m2_13*nz*nx^2*pV2yNi*m1_22-m1_22*m2_21*nx^3*m1_13-m1_22*ny^3*pV2xNi*m1_13*m2_31+pV1yNi*m1_31*m2_12*ny*nx^2*m1_13+m1_11*m2_13*nz*ny^2*pV2yNi*m1_22+m1_11*m2_13*nz^3*pV2yNi*m1_22+m1_11*nx^3*pV2yNi*m1_23*m2_32-m1_21*nx*ny^2*m1_12*m2_23-m1_21*nx^3*m1_12*m2_23-m1_21*m2_12*ny^3*m1_13+m1_12*m2_23*nz^3*pV2xNi*m1_21+m1_12*ny^3*pV2xNi*m1_23*m2_31+m1_12*ny*nz^2*pV2xNi*m1_23*m2_31+m1_12*m2_21*nx*ny^2*m1_23-m1_23*nz*ny^2*pV2xNi*m1_12*m2_21+pV1xNi*m1_22*ny*nx^2*m1_31*m2_13+pV1xNi*m1_23*nz^3*pV2xNi*m1_32*m2_21+pV1xNi*m1_23*nz^3*pV2yNi*m1_31*m2_12+pV1yNi*m1_33*ny^3*m2_32*pV2xNi*m1_11-m1_23*nz*nx^2*pV2yNi*m1_11*m2_12-pV1yNi*m1_11*m2_12*ny*nx^2*m1_33-pV1yNi*m1_11*m2_12*ny^3*m1_33-pV1yNi*m1_11*m2_12*ny*nz^2*m1_33-m2_11*pV1yNi*m1_32*ny*nz^2*m1_13-m2_11*m1_13*nz*ny^2*pV2yNi*m1_22-m1_23*m2_31*nx*nz^2*pV2yNi*m1_12-pV1yNi*m1_11*nx^3*pV2yNi*m1_33*m2_32-pV1yNi*m1_11*m2_13*nz^3*pV2yNi*m1_32+pV1yNi*m1_32*m2_21*nx*nz^2*m1_13+pV1yNi*m1_32*ny^3*pV2xNi*m1_13*m2_31+pV1yNi*m1_31*nx*ny^2*m1_12*m2_23+pV1yNi*m1_33*nz^3*pV2yNi*m1_11*m2_12+m1_12*m2_21*nx^3*m1_23-m2_11*pV1yNi*m1_33*nz^3*pV2yNi*m1_12+m2_11*pV1xNi*m1_32*ny*nz^2*m1_23+m1_12*ny*nz^2*m1_21*m2_13-m1_21*m2_12*ny*nz^2*m1_13-m1_22*ny*nx^2*m1_11*m2_13+m1_11*m2_12*ny*nx^2*m1_23-m1_21*m2_12*ny*nx^2*m1_13+m1_11*nx*ny^2*m1_22*m2_23+pV1yNi*m1_33*nz*nx^2*pV2xNi*m1_12*m2_21+pV1xNi*m1_21*m2_13*nz^3*pV2yNi*m1_32+pV1xNi*m1_22*ny^3*pV2xNi*m1_33*m2_31+pV1xNi*m1_22*ny*nz^2*pV2xNi*m1_33*m2_31+pV1yNi*m1_31*m2_12*ny^3*m1_13+pV1yNi*m1_31*m2_12*ny*nz^2*m1_13-pV1yNi*m1_13*nz*nx^2*pV2yNi*m1_31*m2_12-pV1yNi*m1_11*nx*ny^2*pV2yNi*m1_33*m2_32-pV1yNi*m1_12*ny*nx^2*pV2xNi*m1_33*m2_31-pV1yNi*m1_13*nz^3*pV2yNi*m1_31*m2_12-pV1yNi*m1_11*nx*nz^2*pV2yNi*m1_33*m2_32-pV1yNi*m1_13*nz*ny^2*pV2xNi*m1_32*m2_21-pV1yNi*m1_13*nz*ny^2*pV2yNi*m1_31*m2_12-m1_23*nz^3*pV2xNi*m1_12*m2_21+m1_13*nz^3*pV2yNi*m1_21*m2_12-m1_23*ny^3*m2_32*pV2xNi*m1_11+m1_13*ny^3*m2_32*pV2xNi*m1_21+pV1xNi*m1_21*m2_12*ny^3*m1_33+pV1xNi*m1_22*m2_21*nx^3*m1_33+pV1xNi*m1_21*nx^3*m1_32*m2_23+pV1xNi*m1_23*ny^3*m2_32*pV2xNi*m1_31+pV1xNi*m1_23*nz*ny^2*pV2yNi*m1_31*m2_12+pV1yNi*m1_33*nz*ny^2*pV2yNi*m1_11*m2_12+pV1yNi*m1_33*ny*m2_32*nx^2*pV2xNi*m1_11+pV1yNi*m1_33*ny*m2_32*nz^2*pV2xNi*m1_11+m1_13*ny*m2_32*nz^2*pV2xNi*m1_21+m1_11*m2_13*nz*nx^2*pV2yNi*m1_22+pV1xNi*m1_22*ny*nz^2*m1_31*m2_13-pV1yNi*m1_11*nx*nz^2*m1_32*m2_23-m1_23*ny*m2_32*nz^2*pV2xNi*m1_11-m1_21*m2_13*nz^3*pV2yNi*m1_12-pV1yNi*m1_11*m2_13*nz*nx^2*pV2yNi*m1_32-pV1yNi*m1_13*m2_31*nx^3*pV2yNi*m1_32-pV1xNi*m1_31*nx*ny^2*m1_22*m2_23+pV1xNi*m1_21*m2_13*nz*nx^2*pV2yNi*m1_32+pV1xNi*m1_21*m2_13*nz*ny^2*pV2yNi*m1_32+pV1xNi*m1_22*m2_23*nz^3*pV2xNi*m1_31+pV1xNi*m1_22*m2_21*nx*ny^2*m1_33+pV1xNi*m1_22*m2_23*nz*nx^2*pV2xNi*m1_31+pV1xNi*m1_22*m2_23*nz*ny^2*pV2xNi*m1_31+pV1xNi*m1_22*ny*nx^2*pV2xNi*m1_33*m2_31-pV1xNi*m1_32*m2_23*nz*ny^2*pV2xNi*m1_21+m1_13*m2_31*nx^3*pV2yNi*m1_22+m1_13*m2_31*nx*ny^2*pV2yNi*m1_22+m1_13*m2_31*nx*nz^2*pV2yNi*m1_22+pV1yNi*m1_32*ny*nz^2*pV2xNi*m1_13*m2_31+pV1yNi*m1_31*m2_13*nz*ny^2*pV2yNi*m1_12+pV1yNi*m1_31*m2_13*nz^3*pV2yNi*m1_12+pV1yNi*m1_32*ny*nx^2*pV2xNi*m1_13*m2_31+pV1yNi*m1_31*nx*nz^2*m1_12*m2_23+pV1yNi*m1_33*nz^3*pV2xNi*m1_12*m2_21+pV1yNi*m1_32*ny*nx^2*m1_11*m2_13+pV1xNi*m1_21*nx^3*pV2yNi*m1_33*m2_32+pV1xNi*m1_21*nx*ny^2*pV2yNi*m1_33*m2_32-pV1xNi*m1_31*m2_12*ny*nz^2*m1_23-pV1yNi*m1_12*ny*nz^2*m1_31*m2_13-m1_21*nx*nz^2*m1_12*m2_23-m1_22*m2_21*nx*ny^2*m1_13-m1_22*m2_21*nx*nz^2*m1_13+pV1yNi*m1_32*m2_21*nx*ny^2*m1_13+pV1yNi*m1_32*ny*nz^2*m1_11*m2_13+pV1xNi*m1_23*ny*m2_32*nz^2*pV2xNi*m1_31+pV1xNi*m1_21*nx*nz^2*m1_32*m2_23+pV1xNi*m1_22*m2_21*nx*nz^2*m1_33-pV1xNi*m1_33*m2_31*nx^3*pV2yNi*m1_22-pV1xNi*m1_33*m2_31*nx*nz^2*pV2yNi*m1_22+pV1yNi*m1_32*m2_23*nz^3*pV2xNi*m1_11+m1_13*nz*ny^2*pV2xNi*m1_22*m2_21-pV1yNi*m1_12*m2_23*nz^3*pV2xNi*m1_31-pV1yNi*m1_12*m2_23*nz*ny^2*pV2xNi*m1_31-pV1yNi*m1_13*nz^3*pV2xNi*m1_32*m2_21+pV1xNi*m1_21*m2_12*ny*nz^2*m1_33-pV1xNi*m1_33*ny^3*m2_32*pV2xNi*m1_21-pV1xNi*m1_31*nx*nz^2*m1_22*m2_23-pV1xNi*m1_32*ny*nx^2*m1_21*m2_13-m1_22*m2_23*nz^3*pV2xNi*m1_11+m2_33*pV1xNi*m1_31*nx^3*pV2yNi*m1_22+m2_33*pV1yNi*m1_11*nx^3*pV2yNi*m1_32-m2_33*pV1yNi*m1_31*nx^3*pV2yNi*m1_12-m2_33*pV1yNi*m1_32*ny^3*pV2xNi*m1_11+m2_33*m1_22*ny*nx^2*pV2xNi*m1_11-m2_33*m1_12*ny*nz^2*pV2xNi*m1_21-m2_33*pV1xNi*m1_21*nx^3*pV2yNi*m1_32-m1_21*nx*ny^2*pV2yNi*m1_13*m2_32-m1_21*nx*nz^2*pV2yNi*m1_13*m2_32+m1_12*ny*nx^2*m1_21*m2_13-m1_22*ny*nz^2*pV2xNi*m1_13*m2_31+pV1xNi*m1_21*nx*ny^2*m1_32*m2_23+m2_11*m1_22*ny*nz^2*m1_13+m2_11*m1_22*ny^3*m1_13-m2_11*pV1xNi*m1_23*nz*ny^2*pV2yNi*m1_32-m2_33*pV1yNi*m1_32*ny*nz^2*pV2xNi*m1_11+m2_33*pV1xNi*m1_31*nx*nz^2*pV2yNi*m1_22+m2_33*pV1xNi*m1_31*nx*ny^2*pV2yNi*m1_22+m2_33*pV1yNi*m1_12*ny*nx^2*pV2xNi*m1_31-m2_33*pV1xNi*m1_22*ny*nx^2*pV2xNi*m1_31-m2_33*pV1xNi*m1_22*ny*nz^2*pV2xNi*m1_31-m2_33*pV1xNi*m1_21*nx*nz^2*pV2yNi*m1_32+m2_33*pV1yNi*m1_11*nx*ny^2*pV2yNi*m1_32+m2_33*m1_21*nx*nz^2*pV2yNi*m1_12+m2_33*m1_21*nx*ny^2*pV2yNi*m1_12+m2_11*pV1yNi*m1_13*nz*ny^2*pV2yNi*m1_32+m1_13*nz^3*pV2xNi*m1_22*m2_21-m1_23*m2_31*nx^3*pV2yNi*m1_12-m1_21*m2_13*nz*ny^2*pV2yNi*m1_12-m1_21*nx^3*pV2yNi*m1_13*m2_32-m2_33*m1_11*nx*nz^2*pV2yNi*m1_22+m2_22*m1_23*nz^3*pV2xNi*m1_11-m2_11*pV1yNi*m1_33*nz*ny^2*pV2yNi*m1_12-m2_11*pV1yNi*m1_33*nz*nx^2*pV2yNi*m1_12-m2_11*m1_12*ny*nz^2*m1_23+m2_11*m1_22*ny*nx^2*m1_13+m2_11*pV1xNi*m1_33*nz*nx^2*pV2yNi*m1_22+m2_11*pV1yNi*m1_13*nz*nx^2*pV2yNi*m1_32-m2_11*pV1xNi*m1_23*nz*nx^2*pV2yNi*m1_32+m2_11*pV1yNi*m1_12*ny^3*m1_33-m2_11*pV1yNi*m1_32*ny^3*m1_13+m2_33*m1_22*ny^3*pV2xNi*m1_11-m2_11*m1_12*ny^3*m1_23+m2_11*m1_23*nz^3*pV2yNi*m1_12+m2_11*pV1xNi*m1_33*nz*ny^2*pV2yNi*m1_22-m2_33*m1_11*nx^3*pV2yNi*m1_22+m2_33*m1_21*nx^3*pV2yNi*m1_12-m2_33*m1_12*ny^3*pV2xNi*m1_21+m2_33*pV1yNi*m1_11*nx*nz^2*pV2yNi*m1_32-m2_33*pV1yNi*m1_31*nx*ny^2*pV2yNi*m1_12+m2_11*pV1xNi*m1_32*ny^3*m1_23+m2_33*pV1yNi*m1_12*ny*nz^2*pV2xNi*m1_31-m2_33*pV1yNi*m1_31*nx*nz^2*pV2yNi*m1_12+m2_33*pV1xNi*m1_32*ny*nx^2*pV2xNi*m1_21-m2_33*pV1xNi*m1_21*nx*ny^2*pV2yNi*m1_32-m2_11*m1_12*ny*nx^2*m1_23-m2_33*m1_12*ny*nx^2*pV2xNi*m1_21+m2_33*pV1xNi*m1_32*ny^3*pV2xNi*m1_21-m2_33*m1_11*nx*ny^2*pV2yNi*m1_22-m2_33*pV1xNi*m1_22*ny^3*pV2xNi*m1_31+m2_33*pV1yNi*m1_12*ny^3*pV2xNi*m1_31+m2_33*m1_22*ny*nz^2*pV2xNi*m1_11-pV1yNi*m1_13*ny*m2_32*nx^2*pV2xNi*m1_31-pV1yNi*m1_12*ny*nz^2*pV2xNi*m1_33*m2_31-m1_22*ny*nz^2*m1_11*m2_13+m1_11*nx*ny^2*pV2yNi*m1_23*m2_32+m1_11*nx*nz^2*pV2yNi*m1_23*m2_32+m1_12*m2_23*nz*nx^2*pV2xNi*m1_21+m1_12*m2_23*nz*ny^2*pV2xNi*m1_21+m1_12*ny*nx^2*pV2xNi*m1_23*m2_31-pV1xNi*m1_31*m2_12*ny*nx^2*m1_23+pV1xNi*m1_23*ny*m2_32*nx^2*pV2xNi*m1_31+pV1yNi*m1_31*nx^3*pV2yNi*m1_13*m2_32+pV1yNi*m1_31*nx*nz^2*pV2yNi*m1_13*m2_32+pV1yNi*m1_31*m2_13*nz*nx^2*pV2yNi*m1_12+m1_13*ny*m2_32*nx^2*pV2xNi*m1_21+pV1xNi*m1_23*nz*ny^2*pV2xNi*m1_32*m2_21+pV1xNi*m1_23*nz*nx^2*pV2xNi*m1_32*m2_21+pV1xNi*m1_23*m2_31*nx*ny^2*pV2yNi*m1_32-pV1yNi*m1_11*m2_13*nz*ny^2*pV2yNi*m1_32-m1_22*ny*nx^2*pV2xNi*m1_13*m2_31-pV1yNi*m1_11*nx*ny^2*m1_32*m2_23-pV1yNi*m1_12*ny*nx^2*m1_31*m2_13-m1_22*ny^3*m1_11*m2_13-pV1xNi*m1_31*nx^3*m1_22*m2_23+m2_11*pV1yNi*m1_12*ny*nx^2*m1_33+m2_11*pV1yNi*m1_12*ny*nz^2*m1_33-pV1xNi*m1_32*ny^3*m1_21*m2_13-pV1xNi*m1_32*m2_21*nx*nz^2*m1_23-pV1xNi*m1_31*m2_12*ny^3*m1_23-pV1yNi*m1_12*ny^3*pV2xNi*m1_33*m2_31-pV1yNi*m1_13*m2_31*nx*ny^2*pV2yNi*m1_32-pV1yNi*m1_12*m2_21*nx*ny^2*m1_33-pV1yNi*m1_13*ny^3*m2_32*pV2xNi*m1_31-pV1yNi*m1_12*m2_21*nx^3*m1_33-pV1yNi*m1_12*m2_21*nx*nz^2*m1_33-m1_22*m2_23*nz*ny^2*pV2xNi*m1_11-pV1xNi*m1_33*nz^3*pV2yNi*m1_21*m2_12-pV1xNi*m1_33*nz^3*pV2xNi*m1_22*m2_21-pV1xNi*m1_31*nx*nz^2*pV2yNi*m1_23*m2_32-pV1xNi*m1_32*ny*nx^2*pV2xNi*m1_23*m2_31+pV1xNi*m1_21*m2_12*ny*nx^2*m1_33+pV1yNi*m1_32*m2_21*nx^3*m1_13+pV1yNi*m1_32*m2_23*nz*ny^2*pV2xNi*m1_11-m1_21*m2_13*nz*nx^2*pV2yNi*m1_12-pV1xNi*m1_31*m2_13*nz*ny^2*pV2yNi*m1_22-pV1xNi*m1_33*nz*nx^2*pV2xNi*m1_22*m2_21-pV1xNi*m1_33*nz*nx^2*pV2yNi*m1_21*m2_12+m2_11*pV1xNi*m1_32*ny*nx^2*m1_23+m2_11*m1_23*nz*ny^2*pV2yNi*m1_12+m1_13*nz*nx^2*pV2yNi*m1_21*m2_12+m1_13*nz*nx^2*pV2xNi*m1_22*m2_21-pV1yNi*m1_12*ny^3*m1_31*m2_13-pV1yNi*m1_12*m2_23*nz*nx^2*pV2xNi*m1_31+m2_22*pV1yNi*m1_13*nz^3*pV2xNi*m1_31-m2_22*m1_13*nz*nx^2*pV2xNi*m1_21-m2_22*pV1xNi*m1_21*nx^3*m1_33+m2_11*pV1yNi*m1_13*nz^3*pV2yNi*m1_32+m2_11*m1_23*nz*nx^2*pV2yNi*m1_12-m2_11*pV1xNi*m1_23*nz^3*pV2yNi*m1_32+m2_11*pV1xNi*m1_33*nz^3*pV2yNi*m1_22-m2_11*pV1xNi*m1_22*ny*nx^2*m1_33-m2_11*pV1yNi*m1_32*ny*nx^2*m1_13-m2_22*pV1yNi*m1_33*nz*nx^2*pV2xNi*m1_11-m2_22*pV1xNi*m1_23*nz*ny^2*pV2xNi*m1_31-m1_23*nz*nx^2*pV2xNi*m1_12*m2_21-m2_11*m1_13*nz*nx^2*pV2yNi*m1_22+m2_22*m1_21*nx*ny^2*m1_13);
    
    [pV1xNi, pV1yNi] = MyDeal( ImageToNormalisedImage( polyBoundaryVecCell{imgLoop}{2}(:,bIndGreen), allViews.camera) );    
    [pV2xNi, pV2yNi] = MyDeal( ImageToNormalisedImage( polyBoundaryVecCell{imgLoop}{3}(:,bIndBlue), allViews.camera) );        
    wSolnB = -1/2*(-m1_24*m1_13*m2_21*m2_12-m2_11*m1_24*m1_12*m2_23+m2_11*m1_14*m1_22*m2_23+m1_14*m1_23*m2_21*m2_12-m1_14*m1_22*m2_21*m2_13-m1_14*m1_21*m2_12*m2_23+m1_24*m1_11*m2_12*m2_23+m1_24*m1_12*m2_21*m2_13+m2_22*m2_11*pV1xNi*m1_34*m1_23+m2_22*m2_11*m1_24*m1_13+m2_22*m1_14*m1_21*m2_13-m2_22*m2_11*m1_14*m1_23-m2_11*pV1yNi*m1_14*pV2yNi*m1_33*m2_32+m2_33*m2_22*pV1yNi*m1_14*pV2xNi*m1_31+m2_11*pV1xNi*m1_24*pV2yNi*m1_33*m2_32+m2_22*m1_14*pV2xNi*m1_23*m2_31-m2_11*pV1xNi*m1_34*m1_22*m2_23+m2_11*pV1yNi*m1_34*pV2yNi*m1_13*m2_32-m2_11*pV1yNi*m1_14*m1_32*m2_23+m2_33*m1_14*pV2xNi*m1_22*m2_21-m2_11*pV1xNi*m1_34*pV2yNi*m1_23*m2_32-m2_33*m1_24*pV2yNi*m1_11*m2_12-m2_33*m1_24*pV2xNi*m1_12*m2_21-m2_33*m2_11*m1_14*pV2yNi*m1_22+m2_33*m2_11*m1_24*pV2yNi*m1_12+m2_33*m1_14*pV2yNi*m1_21*m2_12+m2_33*pV1xNi*m1_24*pV2yNi*m1_31*m2_12-m2_33*pV1xNi*m1_34*pV2yNi*m1_21*m2_12-m2_33*pV1yNi*m1_14*pV2yNi*m1_31*m2_12+m2_33*m2_22*m1_24*pV2xNi*m1_11-m2_33*m2_22*pV1xNi*m1_24*pV2xNi*m1_31+m2_11*pV1xNi*m1_24*m1_32*m2_23+m2_33*m2_22*pV1xNi*m1_34*pV2xNi*m1_21+m2_33*pV1yNi*m1_34*pV2xNi*m1_12*m2_21-m2_33*pV1xNi*m1_34*pV2xNi*m1_22*m2_21+m2_33*pV1xNi*m1_24*pV2xNi*m1_32*m2_21-m2_33*pV1yNi*m1_14*pV2xNi*m1_32*m2_21+m2_33*m2_11*pV1xNi*m1_34*pV2yNi*m1_22-m2_33*m2_11*pV1xNi*m1_24*pV2yNi*m1_32-m2_33*m2_11*pV1yNi*m1_34*pV2yNi*m1_12+m2_33*m2_11*pV1yNi*m1_14*pV2yNi*m1_32-m2_33*m2_22*pV1yNi*m1_34*pV2xNi*m1_11-m2_33*m2_22*m1_14*pV2xNi*m1_21+m2_11*m1_14*pV2yNi*m1_23*m2_32-m2_11*m1_24*pV2yNi*m1_13*m2_32+m1_24*pV2xNi*m1_12*m2_31*m2_23+m1_24*pV2xNi*m1_13*m2_21*m2_32+m1_24*pV2yNi*m1_11*m2_32*m2_13-m1_24*pV2yNi*m1_12*m2_31*m2_13+m1_24*pV2yNi*m1_13*m2_31*m2_12+pV1yNi*m1_34*pV2xNi*m1_11*m2_32*m2_23+pV1xNi*m1_34*pV2yNi*m1_23*m2_31*m2_12-m1_14*pV2yNi*m1_21*m2_32*m2_13+m1_14*pV2yNi*m1_22*m2_31*m2_13-m1_14*pV2xNi*m1_22*m2_31*m2_23-m1_14*pV2yNi*m1_23*m2_31*m2_12-m1_24*pV2xNi*m1_11*m2_32*m2_23+pV1yNi*m1_34*m1_13*m2_21*m2_12-pV1yNi*m1_34*m1_11*m2_12*m2_23-m1_14*pV2xNi*m1_23*m2_21*m2_32+m2_11*pV1yNi*m1_34*m1_12*m2_23+pV1xNi*m1_24*pV2xNi*m1_31*m2_32*m2_23-pV1xNi*m1_34*pV2xNi*m1_21*m2_32*m2_23-pV1yNi*m1_34*m1_12*m2_21*m2_13-pV1xNi*m1_24*m1_31*m2_12*m2_23+pV1xNi*m1_34*m1_21*m2_12*m2_23-pV1yNi*m1_34*pV2xNi*m1_12*m2_31*m2_23-pV1yNi*m1_34*pV2xNi*m1_13*m2_21*m2_32-pV1yNi*m1_34*pV2yNi*m1_11*m2_32*m2_13+pV1yNi*m1_34*pV2yNi*m1_12*m2_31*m2_13-pV1yNi*m1_34*pV2yNi*m1_13*m2_31*m2_12+pV1xNi*m1_34*pV2yNi*m1_21*m2_32*m2_13+pV1xNi*m1_34*pV2xNi*m1_23*m2_21*m2_32-pV1xNi*m1_24*pV2xNi*m1_33*m2_21*m2_32-pV1xNi*m1_24*pV2yNi*m1_31*m2_32*m2_13-pV1xNi*m1_24*pV2yNi*m1_33*m2_31*m2_12+pV1xNi*m1_24*pV2yNi*m1_32*m2_31*m2_13+pV1xNi*m1_34*pV2xNi*m1_22*m2_31*m2_23+pV1yNi*m1_14*pV2xNi*m1_33*m2_21*m2_32+pV1yNi*m1_14*pV2yNi*m1_31*m2_32*m2_13-pV1yNi*m1_14*pV2yNi*m1_32*m2_31*m2_13+pV1yNi*m1_14*pV2yNi*m1_33*m2_31*m2_12+pV1yNi*m1_14*m1_31*m2_12*m2_23-pV1yNi*m1_14*m1_33*m2_21*m2_12+pV1yNi*m1_14*m1_32*m2_21*m2_13-pV1xNi*m1_24*pV2xNi*m1_32*m2_31*m2_23-pV1yNi*m1_14*pV2xNi*m1_31*m2_32*m2_23+pV1yNi*m1_14*pV2xNi*m1_32*m2_31*m2_23+pV1xNi*m1_24*m1_33*m2_21*m2_12-pV1xNi*m1_24*m1_32*m2_21*m2_13+m1_14*pV2xNi*m1_21*m2_32*m2_23-pV1xNi*m1_34*pV2yNi*m1_22*m2_31*m2_13-pV1xNi*m1_34*m1_23*m2_21*m2_12+pV1xNi*m1_34*m1_22*m2_21*m2_13-m2_22*pV1xNi*m1_34*m1_21*m2_13-m2_22*pV1yNi*m1_14*m1_31*m2_13+m2_22*pV1xNi*m1_24*pV2xNi*m1_33*m2_31-m2_22*m1_24*pV2xNi*m1_13*m2_31+m2_22*pV1xNi*m1_24*m1_31*m2_13+m2_22*pV1yNi*m1_34*pV2xNi*m1_13*m2_31+m2_22*pV1yNi*m1_34*m1_11*m2_13-m2_22*m2_11*pV1xNi*m1_24*m1_33-m2_22*m2_11*pV1yNi*m1_34*m1_13+m2_22*m2_11*pV1yNi*m1_14*m1_33-m2_22*pV1yNi*m1_14*pV2xNi*m1_33*m2_31-m2_22*m1_24*m1_11*m2_13-m2_22*pV1xNi*m1_34*pV2xNi*m1_23*m2_31+m2_33*pV1yNi*m1_34*pV2yNi*m1_11*m2_12)/(-pV1xNi*m1_31*nx*ny^2*pV2yNi*m1_23*m2_32+pV1xNi*m1_23*nz*nx^2*pV2yNi*m1_31*m2_12-m2_11*m1_13*nz^3*pV2yNi*m1_22+m1_11*nx^3*m1_22*m2_23+m2_22*pV1yNi*m1_13*nz*nx^2*pV2xNi*m1_31-m2_22*pV1xNi*m1_23*nz*nx^2*pV2xNi*m1_31+pV1xNi*m1_22*ny^3*m1_31*m2_13+m1_11*nx*nz^2*m1_22*m2_23-m2_33*pV1yNi*m1_32*ny*nx^2*pV2xNi*m1_11-pV1yNi*m1_13*nz*nx^2*pV2xNi*m1_32*m2_21-pV1xNi*m1_33*m2_31*nx*ny^2*pV2yNi*m1_22+pV1xNi*m1_23*m2_31*nx*nz^2*pV2yNi*m1_32+pV1yNi*m1_31*nx^3*m1_12*m2_23+pV1yNi*m1_31*nx*ny^2*pV2yNi*m1_13*m2_32+m2_22*m1_21*nx^3*m1_13-m2_11*pV1xNi*m1_22*ny^3*m1_33-pV1xNi*m1_33*ny*m2_32*nx^2*pV2xNi*m1_21-pV1yNi*m1_13*m2_31*nx*nz^2*pV2yNi*m1_32-pV1xNi*m1_32*m2_21*nx^3*m1_23+m2_33*pV1xNi*m1_32*ny*nz^2*pV2xNi*m1_21+m1_11*m2_12*ny^3*m1_23-pV1xNi*m1_33*ny*m2_32*nz^2*pV2xNi*m1_21+m1_12*m2_21*nx*nz^2*m1_23-m1_23*nz^3*pV2yNi*m1_11*m2_12-m2_22*m1_11*nx^3*m1_23+m1_12*ny^3*m1_21*m2_13-pV1yNi*m1_13*ny*m2_32*nz^2*pV2xNi*m1_31-pV1xNi*m1_32*ny*nz^2*pV2xNi*m1_23*m2_31+m1_11*m2_12*ny*nz^2*m1_23+m2_22*pV1yNi*m1_11*nx*ny^2*m1_33-m2_22*pV1yNi*m1_31*nx^3*m1_13+m2_22*pV1yNi*m1_11*nx*nz^2*m1_33-m2_22*pV1yNi*m1_33*nz^3*pV2xNi*m1_11-m2_22*pV1xNi*m1_21*nx*nz^2*m1_33-m2_22*m1_11*nx*ny^2*m1_23+m2_22*pV1xNi*m1_31*nx^3*m1_23-m2_22*m1_13*nz*ny^2*pV2xNi*m1_21-m2_22*pV1yNi*m1_31*nx*nz^2*m1_13+m2_22*m1_23*nz*nx^2*pV2xNi*m1_11+m2_22*pV1yNi*m1_11*nx^3*m1_33-m2_22*pV1yNi*m1_33*nz*ny^2*pV2xNi*m1_11+m2_22*pV1yNi*m1_13*nz*ny^2*pV2xNi*m1_31+m2_22*pV1xNi*m1_33*nz*nx^2*pV2xNi*m1_21+m2_22*pV1xNi*m1_33*nz*ny^2*pV2xNi*m1_21+m2_22*m1_21*nx*nz^2*m1_13+m2_22*pV1xNi*m1_31*nx*nz^2*m1_23+m2_22*pV1xNi*m1_33*nz^3*pV2xNi*m1_21-pV1xNi*m1_32*m2_23*nz*nx^2*pV2xNi*m1_21+pV1yNi*m1_32*m2_23*nz*nx^2*pV2xNi*m1_11-m1_23*nz*ny^2*pV2yNi*m1_11*m2_12-pV1xNi*m1_32*ny^3*pV2xNi*m1_23*m2_31-pV1xNi*m1_33*nz*ny^2*pV2xNi*m1_22*m2_21-pV1xNi*m1_33*nz*ny^2*pV2yNi*m1_21*m2_12-pV1xNi*m1_32*m2_23*nz^3*pV2xNi*m1_21+pV1xNi*m1_21*nx*nz^2*pV2yNi*m1_33*m2_32-m2_11*pV1xNi*m1_22*ny*nz^2*m1_33+m1_13*nz*ny^2*pV2yNi*m1_21*m2_12-m1_23*m2_31*nx*ny^2*pV2yNi*m1_12-pV1yNi*m1_11*nx^3*m1_32*m2_23+pV1yNi*m1_32*ny^3*m1_11*m2_13+pV1yNi*m1_33*nz*nx^2*pV2yNi*m1_11*m2_12+pV1yNi*m1_33*m2_31*nx^3*pV2yNi*m1_12+pV1yNi*m1_33*m2_31*nx*ny^2*pV2yNi*m1_12+pV1yNi*m1_33*m2_31*nx*nz^2*pV2yNi*m1_12+pV1yNi*m1_33*nz*ny^2*pV2xNi*m1_12*m2_21+pV1xNi*m1_23*m2_31*nx^3*pV2yNi*m1_32-m1_23*ny*m2_32*nx^2*pV2xNi*m1_11-m2_22*pV1xNi*m1_21*nx*ny^2*m1_33+m2_22*pV1xNi*m1_31*nx*ny^2*m1_23-m2_22*pV1xNi*m1_23*nz^3*pV2xNi*m1_31-m2_22*m1_13*nz^3*pV2xNi*m1_21-m2_22*m1_11*nx*nz^2*m1_23+m2_22*m1_23*nz*ny^2*pV2xNi*m1_11-m2_22*pV1yNi*m1_31*nx*ny^2*m1_13-pV1xNi*m1_31*nx^3*pV2yNi*m1_23*m2_32-pV1xNi*m1_31*m2_13*nz^3*pV2yNi*m1_22-pV1xNi*m1_32*ny*nz^2*m1_21*m2_13-pV1xNi*m1_32*m2_21*nx*ny^2*m1_23-m1_22*m2_23*nz*nx^2*pV2xNi*m1_11-pV1xNi*m1_31*m2_13*nz*nx^2*pV2yNi*m1_22-m1_22*m2_21*nx^3*m1_13-m1_22*ny^3*pV2xNi*m1_13*m2_31+pV1yNi*m1_31*m2_12*ny*nx^2*m1_13+m1_11*m2_13*nz*ny^2*pV2yNi*m1_22+m1_11*m2_13*nz^3*pV2yNi*m1_22+m1_11*nx^3*pV2yNi*m1_23*m2_32-m1_21*nx*ny^2*m1_12*m2_23-m1_21*nx^3*m1_12*m2_23-m1_21*m2_12*ny^3*m1_13+m1_12*m2_23*nz^3*pV2xNi*m1_21+m1_12*ny^3*pV2xNi*m1_23*m2_31+m1_12*ny*nz^2*pV2xNi*m1_23*m2_31+m1_12*m2_21*nx*ny^2*m1_23-m1_23*nz*ny^2*pV2xNi*m1_12*m2_21+pV1xNi*m1_22*ny*nx^2*m1_31*m2_13+pV1xNi*m1_23*nz^3*pV2xNi*m1_32*m2_21+pV1xNi*m1_23*nz^3*pV2yNi*m1_31*m2_12+pV1yNi*m1_33*ny^3*m2_32*pV2xNi*m1_11-m1_23*nz*nx^2*pV2yNi*m1_11*m2_12-pV1yNi*m1_11*m2_12*ny*nx^2*m1_33-pV1yNi*m1_11*m2_12*ny^3*m1_33-pV1yNi*m1_11*m2_12*ny*nz^2*m1_33-m2_11*pV1yNi*m1_32*ny*nz^2*m1_13-m2_11*m1_13*nz*ny^2*pV2yNi*m1_22-m1_23*m2_31*nx*nz^2*pV2yNi*m1_12-pV1yNi*m1_11*nx^3*pV2yNi*m1_33*m2_32-pV1yNi*m1_11*m2_13*nz^3*pV2yNi*m1_32+pV1yNi*m1_32*m2_21*nx*nz^2*m1_13+pV1yNi*m1_32*ny^3*pV2xNi*m1_13*m2_31+pV1yNi*m1_31*nx*ny^2*m1_12*m2_23+pV1yNi*m1_33*nz^3*pV2yNi*m1_11*m2_12+m1_12*m2_21*nx^3*m1_23-m2_11*pV1yNi*m1_33*nz^3*pV2yNi*m1_12+m2_11*pV1xNi*m1_32*ny*nz^2*m1_23+m1_12*ny*nz^2*m1_21*m2_13-m1_21*m2_12*ny*nz^2*m1_13-m1_22*ny*nx^2*m1_11*m2_13+m1_11*m2_12*ny*nx^2*m1_23-m1_21*m2_12*ny*nx^2*m1_13+m1_11*nx*ny^2*m1_22*m2_23+pV1yNi*m1_33*nz*nx^2*pV2xNi*m1_12*m2_21+pV1xNi*m1_21*m2_13*nz^3*pV2yNi*m1_32+pV1xNi*m1_22*ny^3*pV2xNi*m1_33*m2_31+pV1xNi*m1_22*ny*nz^2*pV2xNi*m1_33*m2_31+pV1yNi*m1_31*m2_12*ny^3*m1_13+pV1yNi*m1_31*m2_12*ny*nz^2*m1_13-pV1yNi*m1_13*nz*nx^2*pV2yNi*m1_31*m2_12-pV1yNi*m1_11*nx*ny^2*pV2yNi*m1_33*m2_32-pV1yNi*m1_12*ny*nx^2*pV2xNi*m1_33*m2_31-pV1yNi*m1_13*nz^3*pV2yNi*m1_31*m2_12-pV1yNi*m1_11*nx*nz^2*pV2yNi*m1_33*m2_32-pV1yNi*m1_13*nz*ny^2*pV2xNi*m1_32*m2_21-pV1yNi*m1_13*nz*ny^2*pV2yNi*m1_31*m2_12-m1_23*nz^3*pV2xNi*m1_12*m2_21+m1_13*nz^3*pV2yNi*m1_21*m2_12-m1_23*ny^3*m2_32*pV2xNi*m1_11+m1_13*ny^3*m2_32*pV2xNi*m1_21+pV1xNi*m1_21*m2_12*ny^3*m1_33+pV1xNi*m1_22*m2_21*nx^3*m1_33+pV1xNi*m1_21*nx^3*m1_32*m2_23+pV1xNi*m1_23*ny^3*m2_32*pV2xNi*m1_31+pV1xNi*m1_23*nz*ny^2*pV2yNi*m1_31*m2_12+pV1yNi*m1_33*nz*ny^2*pV2yNi*m1_11*m2_12+pV1yNi*m1_33*ny*m2_32*nx^2*pV2xNi*m1_11+pV1yNi*m1_33*ny*m2_32*nz^2*pV2xNi*m1_11+m1_13*ny*m2_32*nz^2*pV2xNi*m1_21+m1_11*m2_13*nz*nx^2*pV2yNi*m1_22+pV1xNi*m1_22*ny*nz^2*m1_31*m2_13-pV1yNi*m1_11*nx*nz^2*m1_32*m2_23-m1_23*ny*m2_32*nz^2*pV2xNi*m1_11-m1_21*m2_13*nz^3*pV2yNi*m1_12-pV1yNi*m1_11*m2_13*nz*nx^2*pV2yNi*m1_32-pV1yNi*m1_13*m2_31*nx^3*pV2yNi*m1_32-pV1xNi*m1_31*nx*ny^2*m1_22*m2_23+pV1xNi*m1_21*m2_13*nz*nx^2*pV2yNi*m1_32+pV1xNi*m1_21*m2_13*nz*ny^2*pV2yNi*m1_32+pV1xNi*m1_22*m2_23*nz^3*pV2xNi*m1_31+pV1xNi*m1_22*m2_21*nx*ny^2*m1_33+pV1xNi*m1_22*m2_23*nz*nx^2*pV2xNi*m1_31+pV1xNi*m1_22*m2_23*nz*ny^2*pV2xNi*m1_31+pV1xNi*m1_22*ny*nx^2*pV2xNi*m1_33*m2_31-pV1xNi*m1_32*m2_23*nz*ny^2*pV2xNi*m1_21+m1_13*m2_31*nx^3*pV2yNi*m1_22+m1_13*m2_31*nx*ny^2*pV2yNi*m1_22+m1_13*m2_31*nx*nz^2*pV2yNi*m1_22+pV1yNi*m1_32*ny*nz^2*pV2xNi*m1_13*m2_31+pV1yNi*m1_31*m2_13*nz*ny^2*pV2yNi*m1_12+pV1yNi*m1_31*m2_13*nz^3*pV2yNi*m1_12+pV1yNi*m1_32*ny*nx^2*pV2xNi*m1_13*m2_31+pV1yNi*m1_31*nx*nz^2*m1_12*m2_23+pV1yNi*m1_33*nz^3*pV2xNi*m1_12*m2_21+pV1yNi*m1_32*ny*nx^2*m1_11*m2_13+pV1xNi*m1_21*nx^3*pV2yNi*m1_33*m2_32+pV1xNi*m1_21*nx*ny^2*pV2yNi*m1_33*m2_32-pV1xNi*m1_31*m2_12*ny*nz^2*m1_23-pV1yNi*m1_12*ny*nz^2*m1_31*m2_13-m1_21*nx*nz^2*m1_12*m2_23-m1_22*m2_21*nx*ny^2*m1_13-m1_22*m2_21*nx*nz^2*m1_13+pV1yNi*m1_32*m2_21*nx*ny^2*m1_13+pV1yNi*m1_32*ny*nz^2*m1_11*m2_13+pV1xNi*m1_23*ny*m2_32*nz^2*pV2xNi*m1_31+pV1xNi*m1_21*nx*nz^2*m1_32*m2_23+pV1xNi*m1_22*m2_21*nx*nz^2*m1_33-pV1xNi*m1_33*m2_31*nx^3*pV2yNi*m1_22-pV1xNi*m1_33*m2_31*nx*nz^2*pV2yNi*m1_22+pV1yNi*m1_32*m2_23*nz^3*pV2xNi*m1_11+m1_13*nz*ny^2*pV2xNi*m1_22*m2_21-pV1yNi*m1_12*m2_23*nz^3*pV2xNi*m1_31-pV1yNi*m1_12*m2_23*nz*ny^2*pV2xNi*m1_31-pV1yNi*m1_13*nz^3*pV2xNi*m1_32*m2_21+pV1xNi*m1_21*m2_12*ny*nz^2*m1_33-pV1xNi*m1_33*ny^3*m2_32*pV2xNi*m1_21-pV1xNi*m1_31*nx*nz^2*m1_22*m2_23-pV1xNi*m1_32*ny*nx^2*m1_21*m2_13-m1_22*m2_23*nz^3*pV2xNi*m1_11+m2_33*pV1xNi*m1_31*nx^3*pV2yNi*m1_22+m2_33*pV1yNi*m1_11*nx^3*pV2yNi*m1_32-m2_33*pV1yNi*m1_31*nx^3*pV2yNi*m1_12-m2_33*pV1yNi*m1_32*ny^3*pV2xNi*m1_11+m2_33*m1_22*ny*nx^2*pV2xNi*m1_11-m2_33*m1_12*ny*nz^2*pV2xNi*m1_21-m2_33*pV1xNi*m1_21*nx^3*pV2yNi*m1_32-m1_21*nx*ny^2*pV2yNi*m1_13*m2_32-m1_21*nx*nz^2*pV2yNi*m1_13*m2_32+m1_12*ny*nx^2*m1_21*m2_13-m1_22*ny*nz^2*pV2xNi*m1_13*m2_31+pV1xNi*m1_21*nx*ny^2*m1_32*m2_23+m2_11*m1_22*ny*nz^2*m1_13+m2_11*m1_22*ny^3*m1_13-m2_11*pV1xNi*m1_23*nz*ny^2*pV2yNi*m1_32-m2_33*pV1yNi*m1_32*ny*nz^2*pV2xNi*m1_11+m2_33*pV1xNi*m1_31*nx*nz^2*pV2yNi*m1_22+m2_33*pV1xNi*m1_31*nx*ny^2*pV2yNi*m1_22+m2_33*pV1yNi*m1_12*ny*nx^2*pV2xNi*m1_31-m2_33*pV1xNi*m1_22*ny*nx^2*pV2xNi*m1_31-m2_33*pV1xNi*m1_22*ny*nz^2*pV2xNi*m1_31-m2_33*pV1xNi*m1_21*nx*nz^2*pV2yNi*m1_32+m2_33*pV1yNi*m1_11*nx*ny^2*pV2yNi*m1_32+m2_33*m1_21*nx*nz^2*pV2yNi*m1_12+m2_33*m1_21*nx*ny^2*pV2yNi*m1_12+m2_11*pV1yNi*m1_13*nz*ny^2*pV2yNi*m1_32+m1_13*nz^3*pV2xNi*m1_22*m2_21-m1_23*m2_31*nx^3*pV2yNi*m1_12-m1_21*m2_13*nz*ny^2*pV2yNi*m1_12-m1_21*nx^3*pV2yNi*m1_13*m2_32-m2_33*m1_11*nx*nz^2*pV2yNi*m1_22+m2_22*m1_23*nz^3*pV2xNi*m1_11-m2_11*pV1yNi*m1_33*nz*ny^2*pV2yNi*m1_12-m2_11*pV1yNi*m1_33*nz*nx^2*pV2yNi*m1_12-m2_11*m1_12*ny*nz^2*m1_23+m2_11*m1_22*ny*nx^2*m1_13+m2_11*pV1xNi*m1_33*nz*nx^2*pV2yNi*m1_22+m2_11*pV1yNi*m1_13*nz*nx^2*pV2yNi*m1_32-m2_11*pV1xNi*m1_23*nz*nx^2*pV2yNi*m1_32+m2_11*pV1yNi*m1_12*ny^3*m1_33-m2_11*pV1yNi*m1_32*ny^3*m1_13+m2_33*m1_22*ny^3*pV2xNi*m1_11-m2_11*m1_12*ny^3*m1_23+m2_11*m1_23*nz^3*pV2yNi*m1_12+m2_11*pV1xNi*m1_33*nz*ny^2*pV2yNi*m1_22-m2_33*m1_11*nx^3*pV2yNi*m1_22+m2_33*m1_21*nx^3*pV2yNi*m1_12-m2_33*m1_12*ny^3*pV2xNi*m1_21+m2_33*pV1yNi*m1_11*nx*nz^2*pV2yNi*m1_32-m2_33*pV1yNi*m1_31*nx*ny^2*pV2yNi*m1_12+m2_11*pV1xNi*m1_32*ny^3*m1_23+m2_33*pV1yNi*m1_12*ny*nz^2*pV2xNi*m1_31-m2_33*pV1yNi*m1_31*nx*nz^2*pV2yNi*m1_12+m2_33*pV1xNi*m1_32*ny*nx^2*pV2xNi*m1_21-m2_33*pV1xNi*m1_21*nx*ny^2*pV2yNi*m1_32-m2_11*m1_12*ny*nx^2*m1_23-m2_33*m1_12*ny*nx^2*pV2xNi*m1_21+m2_33*pV1xNi*m1_32*ny^3*pV2xNi*m1_21-m2_33*m1_11*nx*ny^2*pV2yNi*m1_22-m2_33*pV1xNi*m1_22*ny^3*pV2xNi*m1_31+m2_33*pV1yNi*m1_12*ny^3*pV2xNi*m1_31+m2_33*m1_22*ny*nz^2*pV2xNi*m1_11-pV1yNi*m1_13*ny*m2_32*nx^2*pV2xNi*m1_31-pV1yNi*m1_12*ny*nz^2*pV2xNi*m1_33*m2_31-m1_22*ny*nz^2*m1_11*m2_13+m1_11*nx*ny^2*pV2yNi*m1_23*m2_32+m1_11*nx*nz^2*pV2yNi*m1_23*m2_32+m1_12*m2_23*nz*nx^2*pV2xNi*m1_21+m1_12*m2_23*nz*ny^2*pV2xNi*m1_21+m1_12*ny*nx^2*pV2xNi*m1_23*m2_31-pV1xNi*m1_31*m2_12*ny*nx^2*m1_23+pV1xNi*m1_23*ny*m2_32*nx^2*pV2xNi*m1_31+pV1yNi*m1_31*nx^3*pV2yNi*m1_13*m2_32+pV1yNi*m1_31*nx*nz^2*pV2yNi*m1_13*m2_32+pV1yNi*m1_31*m2_13*nz*nx^2*pV2yNi*m1_12+m1_13*ny*m2_32*nx^2*pV2xNi*m1_21+pV1xNi*m1_23*nz*ny^2*pV2xNi*m1_32*m2_21+pV1xNi*m1_23*nz*nx^2*pV2xNi*m1_32*m2_21+pV1xNi*m1_23*m2_31*nx*ny^2*pV2yNi*m1_32-pV1yNi*m1_11*m2_13*nz*ny^2*pV2yNi*m1_32-m1_22*ny*nx^2*pV2xNi*m1_13*m2_31-pV1yNi*m1_11*nx*ny^2*m1_32*m2_23-pV1yNi*m1_12*ny*nx^2*m1_31*m2_13-m1_22*ny^3*m1_11*m2_13-pV1xNi*m1_31*nx^3*m1_22*m2_23+m2_11*pV1yNi*m1_12*ny*nx^2*m1_33+m2_11*pV1yNi*m1_12*ny*nz^2*m1_33-pV1xNi*m1_32*ny^3*m1_21*m2_13-pV1xNi*m1_32*m2_21*nx*nz^2*m1_23-pV1xNi*m1_31*m2_12*ny^3*m1_23-pV1yNi*m1_12*ny^3*pV2xNi*m1_33*m2_31-pV1yNi*m1_13*m2_31*nx*ny^2*pV2yNi*m1_32-pV1yNi*m1_12*m2_21*nx*ny^2*m1_33-pV1yNi*m1_13*ny^3*m2_32*pV2xNi*m1_31-pV1yNi*m1_12*m2_21*nx^3*m1_33-pV1yNi*m1_12*m2_21*nx*nz^2*m1_33-m1_22*m2_23*nz*ny^2*pV2xNi*m1_11-pV1xNi*m1_33*nz^3*pV2yNi*m1_21*m2_12-pV1xNi*m1_33*nz^3*pV2xNi*m1_22*m2_21-pV1xNi*m1_31*nx*nz^2*pV2yNi*m1_23*m2_32-pV1xNi*m1_32*ny*nx^2*pV2xNi*m1_23*m2_31+pV1xNi*m1_21*m2_12*ny*nx^2*m1_33+pV1yNi*m1_32*m2_21*nx^3*m1_13+pV1yNi*m1_32*m2_23*nz*ny^2*pV2xNi*m1_11-m1_21*m2_13*nz*nx^2*pV2yNi*m1_12-pV1xNi*m1_31*m2_13*nz*ny^2*pV2yNi*m1_22-pV1xNi*m1_33*nz*nx^2*pV2xNi*m1_22*m2_21-pV1xNi*m1_33*nz*nx^2*pV2yNi*m1_21*m2_12+m2_11*pV1xNi*m1_32*ny*nx^2*m1_23+m2_11*m1_23*nz*ny^2*pV2yNi*m1_12+m1_13*nz*nx^2*pV2yNi*m1_21*m2_12+m1_13*nz*nx^2*pV2xNi*m1_22*m2_21-pV1yNi*m1_12*ny^3*m1_31*m2_13-pV1yNi*m1_12*m2_23*nz*nx^2*pV2xNi*m1_31+m2_22*pV1yNi*m1_13*nz^3*pV2xNi*m1_31-m2_22*m1_13*nz*nx^2*pV2xNi*m1_21-m2_22*pV1xNi*m1_21*nx^3*m1_33+m2_11*pV1yNi*m1_13*nz^3*pV2yNi*m1_32+m2_11*m1_23*nz*nx^2*pV2yNi*m1_12-m2_11*pV1xNi*m1_23*nz^3*pV2yNi*m1_32+m2_11*pV1xNi*m1_33*nz^3*pV2yNi*m1_22-m2_11*pV1xNi*m1_22*ny*nx^2*m1_33-m2_11*pV1yNi*m1_32*ny*nx^2*m1_13-m2_22*pV1yNi*m1_33*nz*nx^2*pV2xNi*m1_11-m2_22*pV1xNi*m1_23*nz*ny^2*pV2xNi*m1_31-m1_23*nz*nx^2*pV2xNi*m1_12*m2_21-m2_11*m1_13*nz*nx^2*pV2yNi*m1_22+m2_22*m1_21*nx*ny^2*m1_13);
    
    wSolnVec(imgLoop,1) = mean([wSolnA, wSolnB]);
    
end


